<?php namespace BoostMyShop\Agent\Console;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class GenerateCatalog extends Command
{
    protected $_logger;
    protected $_curl;
    protected $_config;
    protected $_webserviceHelper;

    public function __construct(
        \Psr\Log\LoggerInterface $logger,
        \Magento\Framework\HTTP\Client\Curl $curl,
        \BoostMyShop\Agent\Model\Config\Agent $config,
        \BoostMyShop\Agent\Helper\WebServices $webserviceHelper
    )
    {
        $this->_logger = $logger;
        $this->_curl = $curl;
        $this->_config = $config;
        $this->_webserviceHelper = $webserviceHelper;
        parent::__construct();
    }

    protected function configure()
    {
        $this->setName('pricinglabagent:generate-catalog');
        $this->setDescription('Generate Boostmyshop Catalog');
        parent::configure();
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        try {
            $state = $this->_webserviceHelper->getObjectManager()->create('Magento\Framework\App\State');
            $state->setAreaCode('adminhtml');
        } catch (\Exception $ex) {
            //nothing
        }

        $output->writeln("START catalog generation");

        try {
            $token = $this->_config->getSetting('authentication/token');
            $this->_curl->get("https://api.pricinglab.com/api/v2/connector/configuration?token=$token&connector=magento2");
            $response = json_decode($this->_curl->getBody(), true);
        } catch (\Exception $ex) {
            $this->_logger->debug('Get configuration call failed : ' . (string)$ex);
        }

        $configuration = [
            'storeId' => $response['context']['storeId'] ?? 0,
            'attributes' => $response['catalog']['attributes'] ?? []
        ];

        $catalogHelper = $this->_webserviceHelper->getObjectManager()->create('BoostMyShop\Agent\Helper\Catalog');
        $catalogHelper->generate($configuration);

        $output->writeln("END catalog generation");
    }
}