<?php namespace BoostMyShop\Agent\Helper\Pricing;

/**
 * @copyright 2015-2016 BoostMyShop (http://www.boostmyshop.com)
 * @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */
class Import extends \Magento\Framework\App\Helper\AbstractHelper
{
    /** @var \Magento\Catalog\Model\Product */
    protected $_productModel;

    /** @var \Magento\Catalog\Model\ResourceModel\Product\Action */
    protected $_productResourceModelAction;

    /** @var \Magento\Eav\Setup\EavSetup */
    private $_eavSetup;

    /** @var \BoostMyShop\Agent\Logger\Logger */
    protected $_logger;

    /** @var \Magento\Eav\Model\AttributeFactory */
    private $_attributeFactory;

    public function __construct(
        \Magento\Catalog\Model\Product                      $product,
        \Magento\Catalog\Model\ResourceModel\Product\Action $productResourceModelAction,
        \Magento\Eav\Setup\EavSetup                         $eavSetup,
        \Magento\Eav\Model\AttributeFactory                 $attributeFactory,
        \Magento\Framework\App\Helper\Context               $context,
        \BoostMyShop\Agent\Logger\Logger                    $logger
    )
    {
        parent::__construct($context);
        $this->_productModel = $product;
        $this->_productResourceModelAction = $productResourceModelAction;
        $this->_attributeFactory = $attributeFactory;
        $this->_eavSetup = $eavSetup;
        $this->_logger = $logger;
    }

    public function execute($pricings, $configuration)
    {
        foreach ($pricings as $pricing) {
            if ($pricing['error'] === 'error' || $pricing['final_price'] == 0) {
                continue;
            }

            $channel = str_replace('_default', '', $pricing['channel']);
            if (!isset($configuration[$channel])) {
                throw new \Exception('Missing configuration for channel: ' . $channel, 400);
            }

            $this->importPricing($pricing['product_id'], $channel, $pricing['final_price'], $configuration[$channel]);
        }
    }

    private function importPricing($sku, $channel, $finalPrice, $configuration)
    {
        try {
//            $productId = $this->_productModel->getIdBySku($sku);
            $productId = $sku;
//            if (!$productId) {
//                $this->_logger->info('No product found with sku: ' . $productId);
//                return;
//            }

            $attributeCode = $configuration['method']['value'] === 'attribute' ? 'pl_' . $channel . '_price' : $configuration['method']['value'];
            $this->createAttributeIfNeeded($attributeCode);
            $attributes = [];
            $attributes[$attributeCode] = $finalPrice;

            $this->_productResourceModelAction->updateAttributes(
                [$productId],
                $attributes,
                $configuration['store']['value']
            );

            $this->_logger->info("[INFO] Product [$productId] attribute [$attributeCode] price [$finalPrice]");
        } catch (\Throwable $e) {
            $error = $e->getMessage();
            $this->_logger->info("[ERROR] $error");
        }
    }

    private function createAttributeIfNeeded($attributeCode)
    {
        $attribute = $this->_eavSetup->getAttribute(\Magento\Catalog\Model\Product::ENTITY, $attributeCode);
        if (!empty($attribute)) {
            return;
        }

        $attributeSetId = $this->_eavSetup->getDefaultAttributeSetId(\Magento\Catalog\Model\Product::ENTITY);
        $attributeGroupId = $this->_eavSetup->getDefaultAttributeGroupId(\Magento\Catalog\Model\Product::ENTITY, $attributeSetId);
        $groupName = $this->_eavSetup->getAttributeGroup(\Magento\Catalog\Model\Product::ENTITY, $attributeSetId, $attributeGroupId, 'attribute_group_name');

        $this->_eavSetup->addAttribute(\Magento\Catalog\Model\Product::ENTITY, $attributeCode, [
            'label' => $attributeCode,
            'user_defined' => false,
            'searchable' => false,
            'visible_on_front' => false,
            'visible_in_advanced_search' => false,
            'group' => $groupName,
            'global' => \Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface::SCOPE_STORE,
        ]);
    }
}
