<?php

namespace BoostMyShop\Agent\Helper;

use Magento\Backend\App\Area\FrontNameResolver;

class WebServices
{
    protected $_coreRegistry = null;
    protected $scopeConfig;

    protected $webServices;
    protected $_configScope;
    protected $_objectManager;

    public function __construct(
        \Magento\Framework\Registry $registry,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfigInterface
    ) {
        $this->_coreRegistry = $registry;
        $this->scopeConfig = $scopeConfigInterface;
    }

    public function processRequest($uri, $method = "GET")
    {
        try {
            $token = $this->getToken();

            if(!$token)
                return null;

            $endpoint = rtrim($this->getConnectConfig("endpoint"),'/');
            $apiURL = $endpoint . $uri;

            $ch = curl_init($apiURL);
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: application/json", "Authorization: Bearer " . $token));
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $result = curl_exec($ch);
            $response = json_decode($result, 1);
            return $response;
        }catch(\Magento\Framework\Webapi\Exception $e)
        {
            return null;
        }
    }

    public function getToken()
    {
        $endpoint = rtrim($this->getConnectConfig("endpoint"),'/');
        $username = $this->getConnectConfig("username");
        $password = $this->getConnectConfig("password");

        if(!$endpoint || !$username || !$password)
            return null;

        $apiURL= $endpoint. "/rest/V1/integration/admin/token";
        $data = array("username" => $username, "password" => $password);
        $data_string = json_encode($data);

        $ch = curl_init($apiURL);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: application/json","Content-Length: ".strlen($data_string)));
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        $token = curl_exec($ch);

        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        switch($httpcode)
        {
            case 401:
                throw new \Exception("Unable to authenticate");
                break;
        }

        $token =  json_decode($token,1);

        return $token;
    }

    public function getConnectConfig($field)
    {
        return $this->scopeConfig->getValue('erpcloud/connect/'.$field, \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

    public function getObjectManager($forceApplyAreaCode = false)
    {
        if (null == $this->_objectManager) {
            $area = $forceApplyAreaCode ? $forceApplyAreaCode: FrontNameResolver::AREA_CODE;
            $this->_configScope = \Magento\Framework\App\ObjectManager::getInstance()->get(\Magento\Framework\Config\ScopeInterface::class);
            $this->_configScope->setCurrentScope($area);
            $this->_objectManager = \Magento\Framework\App\ObjectManager::getInstance();
        }
        return $this->_objectManager;
    }
}