<?php
namespace BoostMyShop\Agent\Model;

use Magento\CatalogInventory\Api\StockRegistryInterface;

class StockManagement
{
    protected $_productCollectionFactory;
    protected $_stockRegistry;

    public function __construct(
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollectionFactory,
        StockRegistryInterface $stockRegistry
    )
    {
        $this->_productCollectionFactory = $productCollectionFactory;
        $this->_stockRegistry = $stockRegistry;
    }

    /**
     * {@inheritdoc}
     */

    public function getStock($productIds)
    {
        $externalProductIds = explode(',', $productIds);

        $data = [];
        
        $productCollection = $this->_productCollectionFactory->create()->addAttributeToSelect('name')->addFieldToFilter('entity_id', ['in' => $externalProductIds]);
        foreach ($productCollection as $product) {
            $productId = $product->getId();
            $data[] = [
                'entity_id' => $productId,
                'quantity' => $this->getProductStockQty($productId),
                'sku' => $product->getsku()
            ];
        }

        return json_encode($data);
    }

   public function getProductStockQty($productId)
   {
       if(!empty($productId)) {
           $stockItem = $this->_stockRegistry->getStockItem($productId);
           return $stockItem->getQty();
       } else {
           return null;
       }
   }
}
