<?php
namespace BoostMyShop\Agent\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;

class OrderCancelAfter implements ObserverInterface
{
    protected $_context;
    protected $scopeConfig;
    protected $webServices;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \BoostMyShop\Agent\Helper\WebServices $webServices
    ) {
        $this->_context = $context;
        $this->scopeConfig = $scopeConfig;
        $this->webServices = $webServices;
    }

    public function execute(EventObserver $observer)
    {
        $sendCancellationRequests = $this->scopeConfig->getValue('erpcloud/connect/send_cancellation_requests', 'default');
        if($sendCancellationRequests)
        {
            $order = $observer->getEvent()->getOrder();

            $url = "/rest/V1/fulfillment/order/".$order->getId()."/cancel_from_external_id";
            $result = $this->webServices->processRequest($url, "PUT");

            if(isset($result['error']) && isset($result['error']['message']) && $result['error']['message'] == 'Order not found')
                return $this;

            if(isset($result['error']) && isset($result['error']['code']) && $result['error']['code'] == 404)
            {
                $errorMsg = isset($result['error']['message']) ? $result['error']['message'] : __('Order can not be canceled');
                $this->_context->getMessageManager()->addError($errorMsg);
                throw new \Exception($errorMsg);
            }
        }

        return $this;
    }

}