<?php

namespace BoostMyShop\Agent\Plugin;

use Magento\Sales\Api\Data\OrderExtensionFactory;
use Magento\Sales\Api\Data\OrderExtensionInterface;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Api\Data\OrderSearchResultInterface;
use Magento\Sales\Model\OrderRepository as MagentoOrderRepository;

class OrderRepositoryPlugin
{
    protected $orderExtensionFactory;
    protected $_configAgent;
    protected $_resource;

    public function __construct(
        OrderExtensionFactory $orderExtensionFactory,
        \BoostMyShop\Agent\Model\Config\Agent $configAgent,
        \Magento\Framework\App\ResourceConnection $resource
    ) {
        $this->orderExtensionFactory = $orderExtensionFactory;
        $this->_configAgent = $configAgent;
        $this->_resource = $resource;
    }

    public function afterGet(MagentoOrderRepository $subject, OrderInterface $order)
    {
        $this->loadOrderExtensionAttributes($order);

        return $order;
    }

    private function loadOrderExtensionAttributes(OrderInterface $order)
    {
        $extensionAttributes = $order->getExtensionAttributes();

        if ($extensionAttributes === null) {
            $extensionAttributes = $this->orderExtensionFactory->create();
        }
        if ($extensionAttributes === null) {
            return;
        }
        try {
            $extensionAttributes->setColissimoRelayId($order->getlpc_relay_id());
            if($locationCode = $this->getLocationCode($order->getId()))
                $extensionAttributes->setPostnlRelayId($locationCode);
            $order->setExtensionAttributes($extensionAttributes);
        } catch (\Throwable $ex) {
            return;
        }
    }

    protected function getLocationCode($orderId)
    {
        if($this->_configAgent->isModuleInstalled('TIG_PostNL')) {
            $connection  = $this->_resource->getConnection();
            $tigPostnlOrder = $connection->getTableName("tig_postnl_order");
            $sql = "SELECT `pg_location_code` FROM ".$tigPostnlOrder." WHERE `order_id` = '".$orderId."'";
            $locationCode = $connection->fetchOne($sql);

            return $locationCode ?? false;
        }
        return false;
    }
    public function afterGetList(MagentoOrderRepository $subject, OrderSearchResultInterface $orderCollection)
    {
        foreach ($orderCollection->getItems() as $order) {
            $this->loadOrderExtensionAttributes($order);
        }

        return $orderCollection;
    }
}
