<?php

namespace BoostMyShop\Agent\Plugin;

use Magento\Catalog\Api\Data\ProductExtensionFactory;

class ProductRepositoryPlugin
{
    protected $_productExtensionFactory;

    public function __construct(
        ProductExtensionFactory $productExtensionFactory
    ) {
        $this->_productExtensionFactory = $productExtensionFactory;
    }

    public function afterGet($subject, $product)
    {
        $this->loadProductExtensionAttributes($product);

        return $product;
    }

    public function loadProductExtensionAttributes($product)
    {
        $extensionAttributes = $product->getExtensionAttributes();

        if ($extensionAttributes === null) {
            $extensionAttributes = $this->_productExtensionFactory->create();
        }

        try {

            $extensionAttributes->setFinalPrice((string)$this->getProductFinalPrice($product));

            $product->setExtensionAttributes($extensionAttributes);

        } catch (\Magento\Framework\Exception\NoSuchEntityException $e) {
        }

        return $product;
    }

    public function getProductFinalPrice($product)
    {
        $finalPrice = null;
        try {
            //set not logged in group on product
            $product->setCustomerGroupId(0);
            $finalPrice = $product->getprice();
            
            if($product->getPriceInfo() && $product->getPriceInfo()->getPrice('final_price')) {
                $finalPrice = $product->getPriceInfo()->getPrice('final_price')->getAmount()->getBaseAmount();
            }
        } catch (\Throwable $e) {
            $finalPrice = $product->getprice();
        }
       
        return $finalPrice;
    }

    public function afterGetList($subject, $searchCriteria)
    {
        $products = [];
        foreach ($searchCriteria->getItems() as $product){
            $products[] = $this->loadProductExtensionAttributes($product);
        }

        $searchCriteria->setItems($products);

        return $searchCriteria;
    }
}
